changeset 749:ee70173c9080 draft

Updated.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Tue, 11 Aug 2015 10:27:15 +0200
parents b01e5b5f851a
children d75f7a3cfe3e
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 65 insertions(+), 60 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Mon Aug 10 13:01:10 2015 +0200
+++ b/ChangeLog	Tue Aug 11 10:27:15 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-11  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated.
+
 2015-08-10  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Mon Aug 10 13:01:10 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Aug 11 10:27:15 2015 +0200
@@ -9736,7 +9736,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9745,13 +9745,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9760,13 +9760,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9775,13 +9775,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9790,13 +9790,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9805,13 +9805,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9820,13 +9820,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9835,13 +9835,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9850,13 +9850,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9865,9 +9865,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
     }
 
     /**
@@ -9736,7 +9736,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.black.
      *